@@ -1,12 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2019-2022 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2019-2023 -- leonerd@leonerd.org.uk
 
 use v5.26; # postfix-deref, signatures
-use Object::Pad 0.73 ':experimental(init_expr)';
+use warnings;
+use Object::Pad 0.800;
 
-package Device::Chip::CC1101 0.08;
+package Device::Chip::CC1101 0.09;
 class Device::Chip::CC1101
    :isa(Device::Chip);
 
@@ -800,9 +801,10 @@ Paul Evans <leonerd@leonerd.org.uk>
 
 __DATA__
 # The following data is automatically generated by update-configs.pl
-common|CCA_MODE=always,CHANSPC_E=0,FEC_EN=1,FOC_BS_CS_GATE=,FREQ=2188650,FS_AUTOCAL=on-unidle,PA_POWER=7,PO_TIMEOUT=x64,RXOFF_MODE=RX,SYNC_MODE=30/32
-GFSK-1.2kb|CHANBW_E=3,CHANBW_M=3,DEVIATION_E=1,DEVIATION_M=5,DRATE_E=5,DRATE_M=131,FREQ_IF=8,FSCAL=2836004881,MOD_FORMAT=GFSK
-GFSK-100kb|AGC_LNA_PRIORITY=lna-first,BS_PRE_KI=KI,BS_PRE_KP=2KP,CHANBW_E=1,CHANBW_M=1,DRATE_E=11,DRATE_M=248,FILTER_LENGTH=32sa,FOC_LIMIT=BW/8,FOC_PRE_K=4K,FREQ_IF=8,FSCAL=3926523921,LNA2MIX_CURRENT=3,LNA_CURRENT=2,MAGN_TARGET=42dB,MAX_DVGA_GAIN=not-top-3,MOD_FORMAT=GFSK,WAIT_TIME=32sa
-GFSK-38.4kb|CHANBW_E=3,DEVIATION_E=3,DEVIATION_M=4,DRATE_E=10,DRATE_M=131,FREQ_IF=6,FSCAL=2836004881,MAX_DVGA_GAIN=not-top,MOD_FORMAT=GFSK
-MSK-250kb|AGC_LNA_PRIORITY=lna-first,BS_PRE_KI=KI,BS_PRE_KP=2KP,CHANBW_E=0,CHANBW_M=2,DEVIATION_E=0,DEVIATION_M=0,DRATE_E=13,DRATE_M=59,FILTER_LENGTH=32sa,FOC_LIMIT=BW/8,FOC_PRE_K=4K,FREQ_IF=11,FSCAL=3926523921,LNA2MIX_CURRENT=3,LNA_CURRENT=2,MAGN_TARGET=42dB,MAX_DVGA_GAIN=not-top-3,MOD_FORMAT=MSK,WAIT_TIME=32sa
-MSK-500kb|BS_PRE_KI=KI,BS_PRE_KP=2KP,CHANBW_E=0,DEVIATION_E=0,DEVIATION_M=0,DRATE_E=14,DRATE_M=59,FILTER_LENGTH=32sa,FOC_LIMIT=BW/8,FOC_PRE_K=4K,FREQ_IF=12,FSCAL=3926523929,LNA2MIX_CURRENT=3,LNA_CURRENT=2,MAGN_TARGET=42dB,MAX_DVGA_GAIN=not-top-3,MOD_FORMAT=MSK,WAIT_TIME=32sa
+common|FOC_BS_CS_GATE=,FREQ=2188650,FS_AUTOCAL=on-unidle,PO_TIMEOUT=x64
+ASK-4.8kb|CHANBW_E=3,DEVIATION_M=0,DRATE_E=7,DRATE_M=131,FREQ_IF=6,FSCAL=3928621087,MAX_DVGA_GAIN=not-top,MOD_FORMAT=ASK,SYNC_MODE=15/16
+GFSK-1.2kb|CCA_MODE=always,CHANBW_E=3,CHANBW_M=3,CHANSPC_E=0,DEVIATION_E=1,DEVIATION_M=5,DRATE_E=5,DRATE_M=131,FEC_EN=1,FREQ_IF=8,FSCAL=2836004881,MOD_FORMAT=GFSK,PA_POWER=7,RXOFF_MODE=RX,SYNC_MODE=30/32
+GFSK-100kb|AGC_LNA_PRIORITY=lna-first,BS_PRE_KI=KI,BS_PRE_KP=2KP,CCA_MODE=always,CHANBW_E=1,CHANBW_M=1,CHANSPC_E=0,DRATE_E=11,DRATE_M=248,FEC_EN=1,FILTER_LENGTH=32sa,FOC_LIMIT=BW/8,FOC_PRE_K=4K,FREQ_IF=8,FSCAL=3926523921,LNA2MIX_CURRENT=3,LNA_CURRENT=2,MAGN_TARGET=42dB,MAX_DVGA_GAIN=not-top-3,MOD_FORMAT=GFSK,PA_POWER=7,RXOFF_MODE=RX,SYNC_MODE=30/32,WAIT_TIME=32sa
+GFSK-38.4kb|CCA_MODE=always,CHANBW_E=3,CHANSPC_E=0,DEVIATION_E=3,DEVIATION_M=4,DRATE_E=10,DRATE_M=131,FEC_EN=1,FREQ_IF=6,FSCAL=2836004881,MAX_DVGA_GAIN=not-top,MOD_FORMAT=GFSK,PA_POWER=7,RXOFF_MODE=RX,SYNC_MODE=30/32
+MSK-250kb|AGC_LNA_PRIORITY=lna-first,BS_PRE_KI=KI,BS_PRE_KP=2KP,CCA_MODE=always,CHANBW_E=0,CHANBW_M=2,CHANSPC_E=0,DEVIATION_E=0,DEVIATION_M=0,DRATE_E=13,DRATE_M=59,FEC_EN=1,FILTER_LENGTH=32sa,FOC_LIMIT=BW/8,FOC_PRE_K=4K,FREQ_IF=11,FSCAL=3926523921,LNA2MIX_CURRENT=3,LNA_CURRENT=2,MAGN_TARGET=42dB,MAX_DVGA_GAIN=not-top-3,MOD_FORMAT=MSK,PA_POWER=7,RXOFF_MODE=RX,SYNC_MODE=30/32,WAIT_TIME=32sa
+MSK-500kb|BS_PRE_KI=KI,BS_PRE_KP=2KP,CCA_MODE=always,CHANBW_E=0,CHANSPC_E=0,DEVIATION_E=0,DEVIATION_M=0,DRATE_E=14,DRATE_M=59,FEC_EN=1,FILTER_LENGTH=32sa,FOC_LIMIT=BW/8,FOC_PRE_K=4K,FREQ_IF=12,FSCAL=3926523929,LNA2MIX_CURRENT=3,LNA_CURRENT=2,MAGN_TARGET=42dB,MAX_DVGA_GAIN=not-top-3,MOD_FORMAT=MSK,PA_POWER=7,RXOFF_MODE=RX,SYNC_MODE=30/32,WAIT_TIME=32sa
